
from .qr_data_factory import IQrDataFactory
from .cdm_proxy import CdmProxy

from json import dumps


class QrCdmFactory(IQrDataFactory):
    def __init__(self, cdm: CdmProxy) -> None:
        self._cdm: CdmProxy = cdm

    def create_json_lite(self) -> str:
        return dumps(self._cdm.data)
